@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10999 2018-04-30 07:30:23Z Lavender $
+# $Id: __init__.py 11168 2018-07-15 02:38:28Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-04-30 15:30:23 +0800 (週一, 30 四月 2018) $
-# $Revision: 10999 $
+# $Date: 2018-07-15 11:38:28 +0900 (週日, 15 七月 2018) $
+# $Revision: 11168 $
 
 import os
 import sys
@@ -325,5 +325,154 @@ def attachPaypalURLs(settings, urlpatterns):
         url(r'^checkout/paypal/place-order/(?P<basket_id>\d+)/$',
             views.SuccessResponseView.as_view(), name='paypal-place-order'),
         url(r'^checkout/paypal/', include('paypal.express.urls')),
+
+        url(r'^(?P<name>.*)/preview/', views.SuccessResponseView2.as_view()),
     )
 
+# ------------------------------------------------------------------------------
+import hashlib
+import time
+import datetime
+
+from django.conf import settings
+from django.template.loader import get_template
+from django.template import Context
+from pyallpay import AllPay
+
+from Iuppiter.Encoding import utf8
+from Iuno.shop.Util import Pay2GoMPGAPI
+
+ECPAY_SANDBOX_SERVICE_URL = \
+                    'https://payment-stage.ecpay.com.tw/Cashier/AioCheckOut/V2'
+ECPAY_SERVICE_URL = 'https://payment.ecpay.com.tw/Cashier/AioCheckOut/V2'
+
+ALLPAY_SANDBOX_SERVICE_URL = \
+                    'http://payment-stage.allpay.com.tw/Cashier/AioCheckOut'
+ALLPAY_SERVICE_URL = 'https://payment.allpay.com.tw/Cashier/AioCheckOut'
+
+SPGATEWAY = 'spgateway'
+ALLPAY = 'allpay'
+ECPAY = 'ecpay'
+
+def buildAPIForm(submission, request, apiName):
+    scheme = request.scheme
+    domain = request.META['HTTP_HOST']
+
+    if not apiName in [SPGATEWAY, ALLPAY, ECPAY]:
+        raise ValueError("Not pay api name: %s" % apiName)
+
+    MERCHANT_TRADE_NO_LEN = 20
+
+    total = submission['order_total'].excl_tax
+    basket = submission['basket']
+    
+    # item name
+    itemName = u''
+    for index, line in enumerate(basket.all_lines()):
+        product = line.product
+        productName = product.get_title()
+        itemName += utf8(productName)
+        
+        itemName += u' %d dollar X %d#' % (line.price_excl_tax, line.quantity)
+    itemName += (u"shipping charge %d dollar X 1" % 
+                 submission['shipping_charge'].excl_tax)
+    
+    # merchantTradeNo
+    basketId = basket.id
+    tradeNo = 'BASKETID%d' % basketId
+    hashCode = hashlib.sha224(str(datetime.datetime.now())).hexdigest().upper()
+    lenNo = (MERCHANT_TRADE_NO_LEN - len(tradeNo))
+    merchantTradeNo = str(hashCode[0:lenNo]) + tradeNo
+    
+
+    # return url
+    RETURN_URL = 'http://localhost:8000/%s/preview/' % apiName
+    CLIENT_BACK_URL = 'http://localhost:8000/'
+    PAYMENT_INFO_URL = 'http://localhost:8000/feedback'
+
+    returnUrl = RETURN_URL.replace(
+                           'localhost:8000', domain).replace('http', scheme)
+    backUrl = CLIENT_BACK_URL.replace(
+                        'localhost:8000', domain).replace('http', scheme)
+
+    # build form data
+    if apiName == SPGATEWAY:
+        data = {
+            'TimeStamp': time.time(),
+            'RespondType': 'JSON',
+            'Version': '1.2',
+            'LangType': 'zh-tw',
+            'MerchantID': settings.SPGATEWAY_API_MERCHANT_ID,
+            'MerchantOrderNo': merchantTradeNo,
+            'Amt': int(total),
+            'ItemDesc': itemName.replace('#', '\n'),
+            'LoginType': 0,
+            'CREDIT': 1,
+            'UNIONPAY': 1,
+        }
+
+        mpg = Pay2GoMPGAPI(
+            hashKey=settings.SPGATEWAY_API_HASH_KEY,
+            hashIv=settings.SPGATEWAY_API_HASH_IV,
+            sandbox=settings.SPGATEWAY_SANDBOX_MODE,
+        )
+
+        payment = mpg.createPayment(data)
+        context = Context({'spgateway': payment,})
+
+        temp = get_template('shop/Payment/Spgateway.html')
+        form = temp.render(context)
+                                      
+        return form
+
+    if apiName in [ECPAY, ALLPAY]:
+        data = {
+            'TotalAmount': int(total), 
+            'ChoosePayment': 'Credit', 
+            'MerchantTradeNo': merchantTradeNo, 
+            'ItemName': itemName,
+            'TradeDesc' : settings.OSCAR_SHOP_NAME, 
+            'Remark' : settings.OSCAR_SHOP_NAME,
+        }
+
+        ap = AllPay(data)
+
+        if apiName == ECPAY:
+            if settings.ECPAY_SANDBOX_MODE:
+                ap.service_url = ECPAY_SANDBOX_SERVICE_URL
+            else:
+                ap.service_url = ECPAY_SERVICE_URL
+
+            ap.url_dict['MerchantID'] = settings.ECPAY_API_MERCHANT_ID
+            ap.HASH_KEY = settings.ECPAY_API_HASH_KEY
+            ap.HASH_IV = settings.ECPAY_API_HASH_IV
+        else:
+            if settings.ALLPAY_SANDBOX_MODE:
+                ap.service_url = ALLPAY_SANDBOX_SERVICE_URL
+            else:
+                ap.service_url = ALLPAY_SERVICE_URL
+
+            ap.url_dict['MerchantID'] = settings.ALLPAY_API_MERCHANT_ID
+            ap.HASH_KEY = settings.ALLPAY_API_HASH_KEY
+            ap.HASH_IV = settings.ALLPAY_API_HASH_IV
+
+
+        # modify return Url
+        ap.url_dict['ReturnURL'] = returnUrl
+        ap.url_dict['OrderResultURL'] = returnUrl
+        ap.url_dict['ClientBackURL'] = backUrl
+
+        dictUrl = ap.check_out()
+
+        if apiName == ECPAY:
+            form = ap.gen_check_out_form(dictUrl, 
+                                    settings.ECPAY_AUTO_SEND_FORM)
+            form = form.replace(u'allPay-Form', u'ecpayForm')
+            form = form.replace(u'allPayForm', u'ecpayForm')
+        else:
+            form = ap.gen_check_out_form(dictUrl, 
+                                    settings.ALLPAY_AUTO_SEND_FORM)
+            form = form.replace(u'allPay-Form', u'allpayForm')
+            form = form.replace(u'allPayForm', u'allpayForm')
+        
+        return form
\ No newline at end of file
